"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.onOrderbookUpdate = void 0;
const exchange_common_1 = require("exchange-common");
const onOrderbookUpdate = (emitter, orderbooks) => {
    emitter.on(exchange_common_1.ActionTypes.Orderbook.Update, (action) => {
        const { order } = action;
        const side = order.side === 'buy' ? 'bids' : 'asks';
        const book = orderbooks[order.market];
        book[side] = book[side].map(m => {
            if (m.orderId === order.orderId) {
                return {
                    ...m,
                    ...order
                };
            }
            return m;
        });
        const price = order.price;
        const amount = book[side].filter(f => f.price === price).reduce((t, o) => t + o.amount - o.filled, 0);
        emitter.emit(`${exchange_common_1.ActionTypes.Orderbook.Update}.${order.market}`, side, price, amount);
    });
    emitter.on(exchange_common_1.ActionTypes.Orderbook.Add, (action) => {
        const { order } = action;
        const side = order.side === 'buy' ? 'bids' : 'asks';
        const book = orderbooks[order.market];
        book[side].push(order);
        const price = order.price;
        const amount = book[side].filter(f => f.price === price).reduce((t, o) => t + o.amount - o.filled, 0);
        emitter.emit(`${exchange_common_1.ActionTypes.Orderbook.Update}.${order.market}`, side, price, amount);
    });
    emitter.on(exchange_common_1.ActionTypes.Orderbook.Delete, (action) => {
        const { order } = action;
        const side = order.side === 'buy' ? 'bids' : 'asks';
        const book = orderbooks[order.market];
        const price = book[side].find(f => f.orderId === order.orderId)?.price;
        if (!price) {
            return;
        }
        book[side] = book[side].filter(f => f.orderId !== order.orderId);
        const amount = book[side].filter(f => f.price === price).reduce((t, o) => t + o.amount - o.filled, 0);
        emitter.emit(`${exchange_common_1.ActionTypes.Orderbook.Update}.${order.market}`, side, price, amount);
    });
};
exports.onOrderbookUpdate = onOrderbookUpdate;
//# sourceMappingURL=onOrderbookUpdate.js.map