import { IApiSign, ICancelBulkOrders, IDeposit, IMessageSuccessAction, IOrder, ITicker, ITrade, IWallet, IWalletUnload, IWithdraw } from 'exchange-common';
import WebSocket from 'ws';
import { ICancelOrder } from './cancelOrder';
import { ISendOrder } from './sendOrder';
interface IEconobitOptions {
    debug?: boolean;
    testnet?: boolean;
}
export declare class Econobit {
    private ws?;
    debug: boolean;
    testnet: boolean;
    private emitter;
    private isLoggedIn;
    private orderbooks;
    constructor(options?: IEconobitOptions);
    private getWS;
    private send;
    connect(): Promise<WebSocket>;
    disconnect(): void;
    get isLogged(): boolean;
    get isConnected(): boolean;
    login(apiSign: IApiSign): Promise<void>;
    logout(): Promise<void>;
    subscribe: {
        ticker: () => Promise<{
            list: {
                [symbol: string]: ITicker;
            };
            onUpdate: (callback: (ticker: ITicker) => void) => void;
        }>;
        orderbook: (market: string) => Promise<{
            orderbook: {
                timestamp: Date;
                bids: {
                    [price: string]: number;
                };
                asks: {
                    [price: string]: number;
                };
                symbol: string;
            };
            onUpdate: (callback: ({ side, price, amount }: {
                side: 'bids' | 'asks';
                price: string;
                amount: number;
            }) => void) => void;
        }>;
        lastTrades: (market: string) => Promise<{
            list: ITrade[];
            onAdd: (callback: (trade: {
                tradeId: number;
                side: 'buy' | 'sell';
                price: number;
                amount: number;
                market: string;
                date: string;
            }) => void) => void;
        }>;
        balances: () => Promise<{
            list: {
                [coin: string]: IWallet;
            };
            onUpdate: (callback: (wallet: IWallet) => void) => void;
        }>;
        openOrders: () => Promise<{
            list: IOrder[];
            onAdd: (callback: (order: IOrder) => void) => void;
            onUpdate: (callback: (order: IOrder) => void) => void;
            onDelete: (callback: (orderId: number) => void) => void;
        }>;
        ordersHistory: () => Promise<{
            list: IOrder[];
            onAdd: (callback: (order: IOrder) => void) => void;
        }>;
        deposits: () => Promise<{
            list: IDeposit[];
            onAdd: (callback: (deposit: IDeposit) => void) => void;
            onUpdate: (callback: (deposit: IDeposit) => void) => void;
        }>;
        withdrawals: () => Promise<{
            list: IWithdraw[];
            onAdd: (callback: (withdraw: IWithdraw) => void) => void;
            onUpdate: (callback: (withdraw: Partial<IWithdraw>) => void) => void;
        }>;
        trades: () => Promise<{
            list: ITrade[];
            onAdd: (callback: (trade: ITrade) => void) => void;
        }>;
    };
    unsubscribe: {
        ticker: () => void;
        orderbook: (symbol: string) => void;
        lastTrades: (symbol: string) => void;
        balances: () => Promise<IWalletUnload>;
        openOrders: () => void;
        ordersHistory: () => void;
        deposits: () => void;
        withdrawals: () => void;
        trades: () => void;
    };
    order: {
        send: (order: ISendOrder) => Promise<IMessageSuccessAction>;
        cancel: (order: ICancelOrder) => Promise<IMessageSuccessAction>;
    };
    bulkOrders: {
        send: (orders: ISendOrder[]) => Promise<IMessageSuccessAction>;
        cancel: (cancelBulkOrders: ICancelBulkOrders) => Promise<IMessageSuccessAction>;
    };
}
export {};
//# sourceMappingURL=econobit.d.ts.map