"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const __1 = require("..");
describe('order', () => {
    const econobit = new __1.Econobit({ testnet: true, debug: false });
    describe('.send', () => {
        beforeAll(async () => {
            const key = '/EE3QeRZEMYxlVseUWsSiQ';
            const secret = 'NZJTQ2+CEm61sUM0wRN/sE03JyFHVJdyisA/rPk443k';
            await econobit.connect();
            await econobit.login({ key, secret });
        });
        test('sending a new order', async () => {
            expect.assertions(1);
            const { onAdd } = await econobit.subscribe.openOrders();
            await new Promise(resolve => {
                econobit.order.send({
                    type: 'limit',
                    amount: 0.0001,
                    side: 'buy',
                    market: 'BTC-BRL',
                    price: 200000
                });
                onAdd(order => {
                    expect(order.market).toBe('BTC-BRL');
                    resolve();
                });
            });
        });
        test('error when try without auth', async () => {
            expect.assertions(2);
            await econobit.logout();
            try {
                await econobit.order.send({
                    type: 'limit',
                    amount: 0.0001,
                    side: 'buy',
                    market: 'BTC-BRL',
                    price: 200000
                });
            }
            catch (err) {
                expect(err.type).toMatch('Message.Errors');
                expect(err.errors).toContain('user_not_logged_in');
            }
            econobit.disconnect();
        });
    });
    describe('.cancel', () => {
        beforeAll(async () => {
            const key = '/EE3QeRZEMYxlVseUWsSiQ';
            const secret = 'NZJTQ2+CEm61sUM0wRN/sE03JyFHVJdyisA/rPk443k';
            await econobit.connect();
            await econobit.login({ key, secret });
        });
        test('canceling the sent order', async () => {
            expect.assertions(1);
            const { list, onDelete } = await econobit.subscribe.openOrders();
            await new Promise(resolve => {
                if (!list[0]) {
                    expect(list.length).toBe(0);
                    return;
                }
                econobit.order.cancel({
                    orderId: list[0].orderId,
                });
                onDelete(orderId => {
                    expect(orderId).toBeTruthy();
                    resolve();
                });
            });
        });
        test('error when try without auth', async () => {
            expect.assertions(2);
            await econobit.logout();
            try {
                await econobit.order.cancel({
                    orderId: 0,
                });
            }
            catch (err) {
                expect(err.type).toMatch('Message.Errors');
                expect(err.errors).toContain('user_not_logged_in');
            }
        });
    });
});
//# sourceMappingURL=order.spec.js.map